@extends('layouts.app')

@section('content')

<h1 class="text-center">Heat Chart</h1> 
<div style="width: 100%; height: 800px" id="svg-container">

<script src="https://cdnjs.cloudflare.com/ajax/libs/d3/7.1.1/d3.min.js" integrity="sha512-COTaPOlz12cG4fSfcBsxZsjauBAyldqp+8FQUM/dZHm+ts/jR4AFoJhCqxy8K10Jrf3pojfsbq7fAPTb1XaVkg==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script>

    //get the data for the agent
    var data = @json($data);
    console.log(data);
    var detectors = @json($detectors);

    var aggr_name = @json($label);

    //console.log(data);
    //console.log(detectors);

    //create a list of all detector names (remove aggregation agents)
    var detector_names = [aggr_name];
    detectors.forEach(function(detector) {
        var name = detector.name;
        if (!name.includes("owa")) {
            detector_names.push(name);
        }
    });

    //go over the evidences retrieved for the given aggregator agent and construct a csv for it
    var csv_data = [];

    detector_names.forEach(function(detector) {
        data.forEach(function(evidence){
            if (detector == evidence.label) {
                csv_data.push({"agent": detector, "subject": JSON.stringify(evidence.subject), "value": evidence.score})
            } else {
                evidence.references.forEach(function(reference) {
                    if (detector == reference.label) {
                        csv_data.push({"agent": detector, "subject": JSON.stringify(reference.subject), "value": reference.score})
                    }
                });
            }
        });
    });
    //console.log(csv_data);

    //draw the heatmap
    // set the dimensions and margins of the graph
    const margin = {top: 80, right: 25, bottom: 30, left: 150},
    width = 400 - margin.left - margin.right,
    height = 450 - margin.top - margin.bottom;

    // append the svg object to the body of the page
    const svg = d3.select("#svg-container")
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", `translate(${margin.left}, ${margin.top})`);

    //Read the csv and draw the heatmap
    

    // Labels of row and columns -> unique identifier of the column called 'agent' and 'subject'
    const myGroups = Array.from(new Set(csv_data.map(d => d.agent)))
    //console.log(myGroups);
    const myVars = Array.from(new Set(csv_data.map(d => d.subject)))
    //console.log(myVars);

    // Build X scales and axis:
    const x = d3.scaleBand()
        .range([ 0, width ])
        .domain(myGroups)
        .padding(0.05);
    svg.append("g")
        .style("font-size", 10)
        .attr("transform", `translate(0, ${height})`)
        .call(d3.axisBottom(x).tickSize(0))
//        .select(".domain").remove()
        .call(x)
            .selectAll("text")
            .style("text-anchor", "end")
            .attr("transform", `translate(0, -${height}) rotate(-315)`)

    // Build Y scales and axis:
    const y = d3.scaleBand()
        .range([ height, 0 ])
        .domain(myVars)
        .padding(0.05);
    svg.append("g")
        .style("font-size", 10)
        .call(d3.axisLeft(y).tickSize(0))
        .select(".domain").remove()

    // Build color scale
    const myColor = d3.scaleLinear().domain([0, 1]).range(["#ffffb3", "red"]);

    // create a tooltip
    const tooltip = d3.select("#svg-container")
        .append("div")
        .style("opacity", 0)
        .attr("class", "tooltip")
        .style("background-color", "white")
        .style("border", "solid")
        .style("border-width", "2px")
        .style("border-radius", "5px")
        .style("padding", "5px")

    // Three function that change the tooltip when user hover / move / leave a cell
    const mouseover = function(event,d) {
        tooltip
        .style("opacity", 1)
        d3.select(this)
        .style("stroke", "black")
        .style("opacity", 1)
    }
    const mousemove = function(event,d) {
        tooltip
        .html("Score: " + d.value)
        .style("left", (event.x)/2 + "px")
        .style("top", (event.y)/2 + "px")
    }
    const mouseleave = function(event,d) {
        tooltip
        .style("opacity", 0)
        d3.select(this)
        .style("stroke", "none")
        .style("opacity", 0.8)
    }

    // add the squares
    svg.selectAll()
        .data(csv_data, function(d) {return d.agent+':'+d.subject;})
        .join("rect")
        .attr("x", function(d) { return x(d.agent) })
        .attr("y", function(d) { return y(d.subject) })
        .attr("rx", 4)
        .attr("ry", 4)
        .attr("width", x.bandwidth() )
        .attr("height", y.bandwidth() )
        .style("fill", function(d) { return myColor(d.value)} )
        .style("stroke-width", 4)
        .style("stroke", "none")
        .style("opacity", 0.8)
        .on("mouseover", mouseover)
        .on("mousemove", mousemove)
        .on("mouseleave", mouseleave)
    

    // // Add title to graph
    // svg.append("text")
    //         .attr("x", 0)
    //         .attr("y", -50)
    //         .attr("text-anchor", "left")
    //         .style("font-size", "22px")
    //         .text("A d3.js heatmap");

    // // Add subtitle to graph
    // svg.append("text")
    //         .attr("x", 0)
    //         .attr("y", -20)
    //         .attr("text-anchor", "left")
    //         .style("font-size", "14px")
    //         .style("fill", "grey")
    //         .style("max-width", 400)
    //         .text("A short description of the take-away message of this chart.");

</script>
@endsection